| Title: | Extra Test Sets for the 'doFuture' Package |
|---|---|
| Description: | Runs examples of packages that use 'foreach' and '%dopar%' for parallelization, where 'doFuture' is used as the 'foreach' adapter making it possible to use any future backend for parallelization. The package tests use these tools to test 'doFuture' with 'foreach'-based examples from packages 'BiocParallel', 'caret', 'doParallel', 'glmnet', 'NMF', 'plyr', and 'TSP'. These tests are run with many known future backends. |
| Authors: | Henrik Bengtsson [aut, cre, cph] |
| Maintainer: | Henrik Bengtsson <[email protected]> |
| License: | LGPL (>= 2.1) |
| Version: | 0.2.0 |
| Built: | 2026-05-16 08:35:35 UTC |
| Source: | https://github.com/futureverse/doFuture.tests.extra |
Run All Examples of the 'caret' Package via Futureverse
caret_examples(exclude = NULL, flavor = NULL)caret_examples(exclude = NULL, flavor = NULL)
exclude |
(optional) A character vector of Rd topics to exclude. |
flavor |
Control how the adapter should behave.
If |
Run All Examples of the 'foreach' Package via Futureverse
foreach_examples(flavor = NULL)foreach_examples(flavor = NULL)
flavor |
Control how the adapter should behave.
If |
Run All Examples of the 'glmnet' Package via Futureverse
glmnet_examples(flavor = NULL)glmnet_examples(flavor = NULL)
flavor |
Control how the adapter should behave.
If |
Run All Examples of the 'plyr' Package via Futureverse
plyr_examples(flavor = NULL)plyr_examples(flavor = NULL)
flavor |
Control how the adapter should behave.
If |
Run one package example
run_example( topic, package, local = FALSE, run.dontrun = TRUE, envir = globalenv() )run_example( topic, package, local = FALSE, run.dontrun = TRUE, envir = globalenv() )
topic |
name or literal character string: the online
|
package |
a character vector giving the package names to look
into for the topic, or |
local |
logical: if |
run.dontrun |
logical indicating that |
envir |
The environment from which variables created by the examples should be removed at the end. |
Invisibly, returns the processing time.
utils::example() is used to run the select example.
Run a package's examples for a specific future plan
run_examples( package, topics = test_topics(package), flavor = NULL, strategy, ... )run_examples( package, topics = test_topics(package), flavor = NULL, strategy, ... )
package |
A package name. |
topics |
One or more Rd topics. |
flavor |
Control how the adapter should behave.
If |
strategy |
A future strategy passed to |
... |
Additional arguments passed to |
Invisibly, returns the processing time.
Get Available Future Strategies
test_strategies()test_strategies()
A character vector of future strategies.
Run All Examples of the 'test_topics' Package via Futureverse
test_topics(package, subset = NA_integer_, max_subset = NULL)test_topics(package, subset = NA_integer_, max_subset = NULL)
package |
A package name. |
subset |
An integer index. |
max_subset |
An integer or NULL. |
Return Rd topics.
Run All Examples of the 'TSP' Package via Futureverse
TSP_examples(flavor = NULL)TSP_examples(flavor = NULL)
flavor |
Control how the adapter should behave.
If |